summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2023-09-19 11:55:09 +0200
committerChristian Grothoff <christian@grothoff.org>2023-09-19 11:55:09 +0200
commit2afcc8c70202c10b71f98c9e4b9766ae08656459 (patch)
tree783a86d49188ee615f338d18793878dc398c522b /src/include
parentdfe576f9379954ab8164da7521bef930d3af3948 (diff)
downloadexchange-2afcc8c70202c10b71f98c9e4b9766ae08656459.tar.gz
exchange-2afcc8c70202c10b71f98c9e4b9766ae08656459.tar.bz2
exchange-2afcc8c70202c10b71f98c9e4b9766ae08656459.zip
complete coin history DB logic to properly handle new ETags
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_exchangedb_plugin.h24
1 files changed, 15 insertions, 9 deletions
diff --git a/src/include/taler_exchangedb_plugin.h b/src/include/taler_exchangedb_plugin.h
index cc71f7770..fc11a292f 100644
--- a/src/include/taler_exchangedb_plugin.h
+++ b/src/include/taler_exchangedb_plugin.h
@@ -4652,23 +4652,29 @@ struct TALER_EXCHANGEDB_Plugin
/**
* Compile a list of all (historic) transactions performed
* with the given coin (melt, refund, recoup and deposit operations).
* Should return 0 if @a etag is already current, otherwise
* return the full history and update @a etag. @a etag
* should be set to the last row ID of the given coin
* in the coin history table.
*
* @param cls the @e cls of this struct with the plugin-specific state
* @param coin_pub coin to investigate
- * @param[in,out] etag known etag, updated to current etag
- * @param[out] tlp set to list of transactions, NULL if coin is fresh
+ * @param start_off starting offset from which on to return entries
+ * @param etag_in up to this offset the client already has a response, do not
+ * return anything unless @a etag_out will be larger
+ * @param[out] etag_out set to the latest history offset known for this @a coin_pub
+ * @param[out] tlp set to list of transactions, set to NULL if coin has no
+ * transaction history past @a start_off or if @a etag_in is equal
+ * to the value written to @a etag_out.
* @return database transaction status
*/
enum GNUNET_DB_QueryStatus
(*get_coin_transactions)(void *cls,
const struct TALER_CoinSpendPublicKeyP *coin_pub,
- uint64_t *etag,
+ uint64_t start_off,
+ uint64_t etag_in,
+ uint64_t *etag_out,
struct TALER_EXCHANGEDB_TransactionList **tlp);
@@ -4652,23 +4652,29 @@ struct TALER_EXCHANGEDB_Plugin
/**
- * Compile a list of all (historic) transactions performed
- * with the given coin (melt, refund, recoup and deposit operations).
- * Should return 0 if @a etag is already current, otherwise
- * return the full history and update @a etag. @a etag
- * should be set to the last row ID of the given coin
- * in the coin history table.
+ * Compile a list of (historic) transactions performed with the given coin
+ * (melt, refund, recoup and deposit operations). Should return 0 if the @a
+ * coin_pub is unknown, otherwise determine @a etag_out and if it is past @a
+ * etag_in return the history after @a start_off. @a etag_out should be set
+ * to the last row ID of the given @a coin_pub in the coin history table.
*
* @param cls the @e cls of this struct with the plugin-specific state